import sys
import getopt
from poe5_instrument import Poe5

__version__ = 'v0.1'

# Port setup for PoE5
comPoE5 = 'COM54'
baudPoE5 = 115200
portStartPoE5 = 1
portStopPoE5 = 24

#Usage poe5_example.py [-p PORTNUMBER] [-c COMPORT] [-b BAUDRATE]
try:
    opts, args = getopt.getopt(sys.argv[1:], "hvp:c:b:",["com=","baud=","port=", "version", "help"])
except getopt.GetoptError:
    print ("poe5_example.py -p <port number 1-24>")
    sys.exit(2)

for opt, arg in opts:
    if opt in ("-c", "--com="):
        comPoE5 = str(arg)
    elif opt in ("-b", "--baud="):
        baudPoE5 = int(arg)
    elif opt in ("-p", "port="):
        if((int(arg) > 0) and (int(arg)<=24)):
            portStartPoE5 = int(arg)
            portStopPoE5 = portStartPoE5
        else:
            print ("poe5_example.py -p [-p PORTNUMBER] [-c COMPORT] [-b BAUDRATE]")
            sys.exit(2)
    elif opt in ("-h", "--help"):
        print ("poe5_example.py [-p PORTNUMBER] [-c COMPORT] [-b BAUDRATE]")
        sys.exit(2)
    elif opt in ("-v", "--version"):
        print ("poe5_example.py version " + __version__)
        sys.exit(2)
    else:
        assert False, "unhandled option"

#setup the comport for the PoE5.
Poe5UUT = Poe5(comPoE5, baudPoE5)

print ("*****************************************************")
print ("*     RT-PoE5 Example Script       " + __version__ + "             *")
print ("*                                                   *")
print ("*****************************************************")
print ("*****************************************************")

#Send setup PoE commands. Example below:
Poe5UUT.cmd('reset')
Poe5UUT.cmd('conn 1,0')
Poe5UUT.cmd('detect ok')
Poe5UUT.cmd('class 1')
Poe5UUT.cmd('set 20')
#Poe5UUT.cmd('auto on')

#print ("Enter any key to exit test.")

#print(":p%s power status %s" % (port,Poe5UUT.statusPort(port)))
while True:

    sys.stdout.write("\r\n")
    for port in range(portStartPoE5,(portStopPoE5+1)):
        port_on = Poe5UUT.statusPort(port)
        if(3 == port_on):
            # main on, alt on
            sys.stdout.write("|p%s on, on" % (port))
        elif(2 == port_on):
            # main off, alt on
            sys.stdout.write("|p%s off, on" % (port))
        elif(1 == port_on):
            # main on, alt off
            sys.stdout.write("|p%s on, off" % (port))
        else:
            # main off, alt off
            sys.stdout.write("|p%s off, off" % (port))
        sys.stdout.write("\r\n")
    #sys.stdout.write("|")
    sys.stdout.flush()

Poe5UUT.closeport()