import sys
import serial
import re

"""
--------------------------------------------------------------------
 Classes to control the operatioin of PoE5 control card.
 
 The commands implemented are not comprehensive.
 
 Note: Not all functions have been tested.

Revision History:

USAGE EXAMPLE
 
--------------------------------------------------------------------
"""
## ****************************************************************************
##  A class for the PoE5 control card.
## ****************************************************************************
class Poe5():

    def __init__(self, portNum, comBaud=9600):
        try:
            self.raw = serial.Serial(portNum,comBaud,timeout=1)
        except serial.SerialException:
            print ("Failed to open serial port!")
            sys.exit(2)
        print ('INIT: PoE3 setup on port ' + str(portNum) + ' Baud ' + str(comBaud))

    def closeport(self):
        self.raw.close()
        
## ****************************************************************************   
    def swrite(self,buffer):
        return self.raw.write(buffer+'\r')

    def sread(self):
        inChar = self.raw.read()
        inBuff = inChar
        while (inChar != '>') or ("RT-PoE" not in inBuff):
            inChar = self.raw.read()
            inBuff += inChar
        #print (inBuff)
        return inBuff
        
    def ask(self,buffer):
        self.swrite(buffer)
        return self.raw.sread()

    ## Sends a PoE5 command.
    def sendCmd(self, buffer):
        self.swrite(buffer)
        inBuf = self.sread()
        #print inBuf
        if "RT-PoE5" not in inBuf:
            print ('!Error in sendCmd response')
            return 0
        return inBuf

    ## Sends a system command and returns the response
    def cmd(self, buffer):
        return self.sendCmd(buffer)
            
    ## Edgar command send.
    ## Sends a command to aport 
    def cmdPort(self, aport, buffer):
        outBuf = 'p' + str(aport) + ' ' + buffer
        return self.sendCmd(outBuf)
        
    ## Edgar group command send.
    ## Sends a command to a group
    def cmdGroup(self, agroup, buffer):
        outBuf = 'g' + str(agroup) + ' ' + buffer
        #print (outBuf)
        return self.sendCmd(outBuf)

    # Check power status of a port.
    def statusPort(self, aport):
        outBuf = 'p' + str(aport) + ' ' + 'stat'
        response = re.split("\\s+", self.sendCmd(outBuf))
        for idx, item in enumerate(response):
            # should have format ":p1 PWR 0, 0"
            if(item.startswith(":p", )):
                if response[idx+1] == "PWR":
                    #print(response[idx+2])
                    if (response[idx+2] == "1,") and (response[idx+3] == "1"):
                        # main on, alt on
                        return 3
                    elif (response[idx+2] == "0,") and (response[idx+3] == "1"):
                        # main off, alt on
                        return 2
                    elif (response[idx+2] == "1,") and (response[idx+3] == "0"):
                        # main on, alt off
                        return 1
                    else:
                        # main off, alt off
                        return 0